#!/bin/ksh
# ident @(#)tape.cgi	1.1     96/04/05 SMI
#
# Copyright 1996 Sun Microsystems, Inc. All Rights Reserved

MODULE=services/SUNWsbuA
. /opt/netra/SUNWnetra/lib/netra.globals
. $MODLIB/legato.ksh

cgi_post="$UNCGI$MODCGI/tape-chk.cgi"
set +u

#
# This page is meaningless if no tape devices are configured
#
dev=`get_default_device 2>&1`
if [[ $dev = *"RPC error"* ]]; then
        netra_html_info "$NO_DAEMON_BANNER"
	netra_html_head "Tape Inventory"
	print "$NO_DAEMON_ERR"
	netra_html_tail -u $MODCGI/index.cgi \
			-h $UNCGI$MODCGI/index_help.cgi?op=tape
	exit 0
fi

if [[ $dev = '' ]]; then
        netra_html_info "No backup device configured."
	netra_html_head "Tape Inventory"
	netra_html_tail -u $MODCGI/index.cgi \
			-h $UNCGI$MODCGI/index_help.cgi?op=tape
	exit 0
fi

# Output the HTML
#
netra_html_head "Tape Inventory"
print "<FORM METHOD=POST ACTION=\"${cgi_post}\">"

#
# Single tape inventory
#
tapelist=`get_media_inventory 2>&1`
let tapestatus=$?
if [[ $dev = Jukebox* ]]; then
	jblist=`get_jukebox_inventory 2>&1`
	let jbstatus=$?
else
	jblist=""
	let jbstatus=0
fi

if [[ $tapestatus -ne 0 ]]; then
	print "Couldn't get tape status:<BR><PRE>$tapelist</PRE>"
elif [[ $tapelist != "" ]]; then
	let started=0
	print "$tapelist" | while read line ; do
		# don't show anything if it's part of a jukebox:
		devname="/dev/rmt/${line##*/dev/rmt/}"
		devname=${devname%%, *}
		if [[ $jblist = *${devname}* ]]; then
			continue
		fi

		# Now we know we're planning to print something, so
		# make sure we've printed the header.  We couldn't
		# print it before entering the loop, since it may have
		# been that we had no non-jukebox single tape devices.
		if [[ $started -eq 0 ]]; then
			let started=1
			cat <<- EOF
				<H3>Single Tape Device Inventory</H3>
				<TABLE BORDER=1><TR><TH align=left>Device</TH>
				<TH align=left>Type</TH>
				<TH align=left>Tape Mounted</TH>
				<TH align=left>Enabled?</TH></TR>
			EOF
		fi

		# line can have the following formats:
		# (nothing) mounted on 8mm tape /dev/rmt/0cbn
		# 4mm tape yeast.005 mounted on /dev/rmt/1mbn, write enabled
		# 8mm 5GB tape netrad14.002 mounted on /dev/rmt/0hbn, \
		#	write protected
		# These three cases have to be considered separately.
		print "$line" | nawk '{
			if ($NF == "disabled")
				enabled="No";
			else
				enabled="Yes";
			if ($1 == "(nothing)") {
				type = $4;
				name="(none)";
				device = $6;
			} else if ($2 == "5GB") {
				type = $1 " " $2;
				name = $4;
				device = $5;
			} else {
				type = $1;
				name = $3;
				device = $6;
			}
			gsub(",", "", device);
			printf("<TR><TD>%s<TD>%s<TD>%s<TD>%s</TR>\n",
				device, type, name, enabled);
		}'
	done
	if [[ $started -ne 0 ]]; then
		cat <<- EOF
			</TABLE>
			<HR>
			In case a manual mount or dismount of the tape 
			is required, press the appropriate button:
			<P>
			<TR><TD><INPUT TYPE="submit" name="action"
				 value="MOUNT"></TD>
			    <TD><INPUT TYPE="submit" name="action"
				 value="UNMOUNT"></TD></TR>
		EOF
	fi
fi

#
# Jukebox inventory
#
# nsrjb -C returns 3 for "jukebox not supported",
# which we don't consider to be an error worth reporting.
if [[ $jbstatus -eq 3 ]]; then
	# do nothing
	print "$jblist"
elif [[ $jbstatus -ne 0 ]]; then
	print "Couldn't get jukebox status:<BR><PRE>$jblist</PRE>"
elif [[ $jblist != "" ]]; then
	cat <<- EOF
		<H3>Jukebox Inventory</H3>
		<TABLE BORDER=1><TR><TH>Jukebox</TH><TH>Tape Slots</TH></TR>
	EOF
	jbname=""
	slots=""
	print "$jblist" | while read line ; do
		if [[ $line = Jukebox* ]]; then
			if [[ $jbname != "" ]]; then
				print "<TR><TH ROWSPAN=$numslots>$jbname$slots"
			fi
			let numslots=0
			slots=""
			jbname=${line#* }
			jbname=${jbname%:}
		elif [[ $line = *( )+([0-9]):* ]]; then
			name=$( print $line | awk '{ print $2; }' )
			if [[ $name = "" ]]; then
				name="[empty]"
			fi
			if [[ $slots = "" ]]; then
				slots="<TD>$name</TD></TR>"
			else
				slots="$slots\n<TR><TD>$name</TD></TR>"
			fi
			let numslots=$numslots+1
		elif [[ $line = *mounted* ]]; then
			#mounted=${line##*slot*([ ])+([0-9]): }
			#mounted=${line##*: }
			name=${line%% \(mounted\)}
			name=${name##* }
			slots=$( print "$slots" \
				| sed "s/$name/$name (mounted)/" )
		fi
	done
	if [[ $jbname != "" ]]; then
		print "<TR><TH ROWSPAN=$numslots>$jbname$slots"
	fi
	print "</TABLE>"

	cat <<- EOF
		<HR>
		<TABLE>
		<TR><TD>
		<INPUT TYPE="submit" name="action" value="UNLOAD"></TD>
		</TD><TD>Unload all tapes from the jukebox</TD></TR>
		<TR><TD>
		<INPUT TYPE="submit" name="action" value="JUKEBOX INVENTORY">
		</TD><TD>Verify the jukebox inventory by checking each tape
		<br>Warning: this takes a long time.</TD></TR>
	EOF

	# mmrecov doesn't understand jukeboxes or auto media management,
	# so the user must manually advance to the next jukebox tape
	# and then mount the tape to tell mmrecov that the next tape
	# is ready, so we must offer a MOUNT button in this case:
	daemons=$(get_daemon_list)
	if [[ $daemons = *mmrecov* ]]; then
		cat <<- MOUNTEOF
			<TR><TD><INPUT TYPE="submit" name="action"
				 value="MOUNT"></TD>
			    <TD>When recovering index files spanning multiple
				tapes, you must manually advance the jukebox
				to the next tape in the sequence, then press
				this MOUNT button.
			</TR>
		MOUNTEOF
	fi
	print "</TABLE>"
fi

netra_html_tail -u $MODCGI/index.cgi \
	-h $UNCGI$MODCGI/index_help.cgi?op=tape
set -u
